@@ -60,7 +60,7 @@ class CfnScalingPlan(
             scaling_instructions=scaling_instructions,
         )
 
-        jsii.create(CfnScalingPlan, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
